# Security Policy

## Supported Versions

Only the latest release of anypinn receives security fixes.

| Version | Supported |
| ------- | --------- |
| latest  | ✓         |
| older   | ✗         |

## Reporting a Vulnerability

**Please do not report security vulnerabilities through public GitHub issues.**

To report a vulnerability, email **giacomo.guidotto@gmail.com** with:

- A description of the vulnerability and its potential impact
- Steps to reproduce or a proof-of-concept
- Any suggested mitigations (optional)

You can expect an acknowledgement within **48 hours** and a status update within **7 days**.

If a vulnerability is confirmed, a fix will be released as soon as possible and credited to the reporter (unless anonymity is preferred).
